#  Copyright (C) 2009 Registro.br. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 1. Redistribution of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
 
import getopt
import getpass

from pydnsshim.LoginRequest import LoginRequest
from pydnsshim.LogoutRequest import LogoutRequest
from pydnsshim.HelloRequest import HelloRequest
from pydnsshim.AddUserRequest import AddUserRequest
from pydnsshim.ChangePasswordRequest import ChangePasswordRequest
from pydnsshim.NewZoneRequest import NewZoneRequest
from pydnsshim.DnskeyAlgorithm import DnskeyAlgorithm
from pydnsshim.ImportZoneRequest import ImportZoneRequest
from pydnsshim.ListZonesRequest import ListZonesRequest
from pydnsshim.PrintZoneRequest import PrintZoneRequest
from pydnsshim.RrRequest import RrRequest
from pydnsshim.RrType import RrType
from pydnsshim.DnsClass import DnsClass
from pydnsshim.PubZoneRequest import PubZoneRequest
from pydnsshim.RemoveZoneRequest import RemoveZoneRequest
from pydnsshim.ZoneVersionRequest import ZoneVersionRequest
from pydnsshim.SetExpirationPeriodRequest import SetExpirationPeriodRequest
from pydnsshim.NewKeyRequest import NewKeyRequest
from pydnsshim.DnskeyFlags import DnskeyFlags
from pydnsshim.DnskeyStatus import DnskeyStatus
from pydnsshim.ImportKeyRequest import ImportKeyRequest
from pydnsshim.ListKeysRequest import ListKeysRequest
from pydnsshim.ChangeKeyStatusRequest import ChangeKeyStatusRequest
from pydnsshim.RemoveKeyRequest import RemoveKeyRequest
from pydnsshim.SlaveGroupRequest import SlaveGroupRequest
from pydnsshim.SlaveOperation import SlaveOperation
from pydnsshim.ListSlaveGroupRequest import ListSlaveGroupRequest
from pydnsshim.ListZonesBySlaveGroupRequest import ListZonesBySlaveGroupRequest
from pydnsshim.PrintSlaveGroupRequest import PrintSlaveGroupRequest
from pydnsshim.SlaveRequest import SlaveRequest
from pydnsshim.ListSlavesRequest import ListSlavesRequest
from pydnsshim.NewTsigKeyRequest import NewTsigKeyRequest
from pydnsshim.RemoveTsigKeyRequest import RemoveTsigKeyRequest
from pydnsshim.ListTsigKeysRequest import ListTsigKeysRequest
from pydnsshim.AddZoneUserRequest import AddZoneUserRequest
from pydnsshim.RemoveZoneUserRequest import RemoveZoneUserRequest

from Dnssh.CommandParserException import CommandParserException

def parseLogin(args):
	opts, args = getopt.getopt(args, 'u:')
	username = ''
	
	for opt, value in opts:
		if (opt == '-u'):
			username = value
		
	if (username == ''):
		raise CommandParserException('Invalid syntax')
		
	password = ''
	password = getpass.getpass("Password: ")
	if (password == ''):
		raise CommandParserException("Invalid password")
	
	loginRequest = LoginRequest()
	loginRequest.username = username
	loginRequest.password = password
	xml = loginRequest.toXml()
	return xml

def parseLogout(sessionId):
	logoutRequest = LogoutRequest()
	logoutRequest.sessionId = sessionId
	xml = logoutRequest.toXml()
	return xml

def parseHello(sessionId):
	helloRequest = HelloRequest()
	helloRequest.sessionId = sessionId
	xml = helloRequest.toXml()
	return xml

def parseAddUser(args):
	opts, args = getopt.getopt(args, 'u:')
	username = ''
	password = ''
	password2 = ''
	
	for opt, value in opts:
		if (opt == '-u'):
			username = value
	
	if (username == ''):
		raise CommandParserException('Invalid syntax')

	password = getpass.getpass("Password: ")
	password2 = getpass.getpass("Confirm password: ")
		
	if (password == '' or password != password2):
		raise CommandParserException("Invalid password")
		
	addUserRequest = AddUserRequest()
	addUserRequest.username = username
	addUserRequest.password = password
	xml = addUserRequest.toXml()
	return xml

def parseChangePassword(args, sessionId):
	opts, args = getopt.getopt(args, 'u:')
	username = ''
	for opt, value in opts:
		if (opt == '-u'):
			username = value
	
	if (username == ''):
		raise CommandParserException('Invalid syntax')
	
	oldPassword = getpass.getpass("Current password: ")
	password = getpass.getpass("New password: ")
		
	if (oldPassword == '' or password == ''):
		raise CommandParserException("Invalid password")
	
	changePasswordRequest = ChangePasswordRequest()
	changePasswordRequest.sessionId = sessionId
	changePasswordRequest.username = username
	changePasswordRequest.oldPassword = oldPassword
	changePasswordRequest.newPassword = password
	xml = changePasswordRequest.toXml()
	return xml

def parseNewZone(args, sessionId):
	options = ['ttl=', 'mname=', 'rname=', 'serial=', 'refresh=', 'retry=', 
					'expire=', 'minimum=', 'no-dnssec', 'key-size=', 'rrsig-validity=']
	opts, args = getopt.getopt(args, 'z:', options)
		
	zonename = ''
	ttl = 86400
	mname = ''
	rname = ''
	serial = 1
	refresh= 86400
	retry = 900
	expire = 604800
	minimum = 900
	dnssec = True
	keySize = 1024
	expiration = 2592000
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '--ttl'):
			ttl = int(value)
		elif (opt == '--mname'):
			mname = value
		elif (opt == '--rname'):
			rname = value
		elif (opt == '--serial'):
			serial = int(value)
		elif (opt == '--refresh'):
			refresh = int(value)
		elif (opt == '--retry'):
			retry = int(value)
		elif (opt == '--expire'):
			expire == int(value)
		elif (opt == '--minimum'):
			minimum = int(value)
		elif (opt == '--no-dnssec'):
			dnssec = False
		elif (opt == '--key-size'):
			keySize = int(value)
		elif (opt == '--rrsig-validity'):
			expiration = int(value)
		
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")
		
	if (mname == ''):
		mname = 'ns1.' + zonename
	
	if (rname == ''):
		rname = 'hostmaster.' + zonename
	
	newZoneRequest = NewZoneRequest()
	newZoneRequest.sessionId = sessionId
	newZoneRequest.zone = zonename
	newZoneRequest.ttl = ttl
	newZoneRequest.mname = mname
	newZoneRequest.rname = rname
	newZoneRequest.serial = serial
	newZoneRequest.refresh = refresh
	newZoneRequest.retry = retry
	newZoneRequest.expire = expire
	newZoneRequest.minimum = minimum
	newZoneRequest.signed = dnssec
	if (dnssec == True):
		newZoneRequest.keySize = keySize
		newZoneRequest.algorithm = DnskeyAlgorithm.RSASHA1
		newZoneRequest.expirationPeriod = expiration
			
	xml = newZoneRequest.toXml()
	return xml

def parseImportZone(args, sessionId):
	opts, args = getopt.getopt(args, 'z:s:p:')
	zonename = ''
	server = ''
	port = 53
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '-s'):
			server = value
		elif (opt == '-p'):
			port = int(value)
		
	if (zonename == '' or server == ''):
		raise CommandParserException("Invalid syntax")

	importZoneRequest = ImportZoneRequest()
	importZoneRequest.sessionId = sessionId
	importZoneRequest.zone = zonename
	importZoneRequest.server = server
	importZoneRequest.port = port
	xml = importZoneRequest.toXml()
	return xml

def parseListZones(sessionId):
	listZonesRequest = ListZonesRequest()
	listZonesRequest.sessionId = sessionId
	xml = listZonesRequest.toXml()
	return xml

def parsePrintZone(args, sessionId):
	opts, args = getopt.getopt(args, 'z:')
	
	zonename = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")

	printZoneRequest = PrintZoneRequest()
	printZoneRequest.sessionId = sessionId
	printZoneRequest.zone = zonename
	xml = printZoneRequest.toXml()
	return xml

def parseRrOperation(args, operation, sessionId):
	opts, args = getopt.getopt(args, 'z:o:t:r:', ['ttl='])
	
	zonename = ''
	ownername = ''
	ttl = 86400
	type = ''
	rdata = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '-o'):
			ownername = value
		elif (opt == '-t'):
			type = value
		elif (opt == '-r'):
			rdata = value
		elif (opt == '--ttl'):
			ttl = int(value)
	
	if (zonename == '' or type == '' or rdata == ''):
		raise CommandParserException("Invalid syntax")
	
	ownername = ownername.replace('"', '')
	ownername = ownername.replace("'", "")
	ownernameLen = len(ownername)
	zoneLen = len(zonename)
	if (ownername[(ownernameLen - zoneLen):] == zonename):
		ownername = ownername[:(ownernameLen-zoneLen)]
		
	if (ownername != "" and ownername[-1] == "."):
		ownername = ownername[:-1]
		
	if (type.upper() == "TXT"):
		rdata = "\"" + rdata + "\""
		
	request = RrRequest()
	request.sessionId = sessionId
	request.op = operation
	request.zone = zonename
	request.ownername = ownername
	request.ttl = ttl
	try:
		request.type = RrType(type)
	except:
		raise CommandParserException('Invalid RR Type')
	
	request.dnsClass = DnsClass.IN
	request.rdata = rdata
	xml = request.toXml()
	return xml

def parsePubZone(args, sessionId):
	opts, args = getopt.getopt(args, 'z:s:if', ['full', 'incremental'])
	
	zonename = ''
	serial = 0
	full = True
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '-s'):
			serial = int(value)
		elif (opt == '-i' or opt == '--incremental'):
			full = False
		elif (opt == '-f' or opt == '--full'):
			full = True
	
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")
	
	pubZoneRequest = PubZoneRequest()
	pubZoneRequest.sessionId = sessionId
	pubZoneRequest.zone = zonename
	pubZoneRequest.serial = serial
	pubZoneRequest.full = full
	xml = pubZoneRequest.toXml()
	return xml

def parseRemoveZone(args, sessionId):
	opts, args = getopt.getopt(args, 'z:')
	
	zonename = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
	
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")
	
	removeZoneRequest = RemoveZoneRequest()
	removeZoneRequest.sessionId = sessionId
	removeZoneRequest.zone = zonename
	xml = removeZoneRequest.toXml()
	return xml

def parseZoneVersion(args, sessionId):
	opts, args = getopt.getopt(args, 'z:')
	
	zonename = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
	
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")
	
	zoneVersionRequest = ZoneVersionRequest()
	zoneVersionRequest.sessionId = sessionId
	zoneVersionRequest.zone  = zonename
	xml = zoneVersionRequest.toXml()
	return xml

def parseSetExpirationPeriod(args, sessionId):
	opts, args = getopt.getopt(args, 'z:', ['rrsig-validity='])
	
	zonename = ''
	expiration = 2592000
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '--rrsig-validity'):
			expiration = int(value)

	if (zonename == ''):
		raise CommandParserException("Invalid syntax")
	
	setExpirationPeriodRequest = SetExpirationPeriodRequest()
	setExpirationPeriodRequest.sessionId = sessionId
	setExpirationPeriodRequest.zone = zonename
	setExpirationPeriodRequest.expiration = expiration
	xml = setExpirationPeriodRequest.toXml()
	return xml

def parseNewKey(args, sessionId):
	opts, args = getopt.getopt(args, 'z:', ['key-size=', 'ksk', 'zsk', 'flags=', 'status='])
	
	zonename = ''
	keySize = 1024
	keyType = 'ZSK'
	flags = DnskeyFlags.SEP_ON
	status = 'SIGN'
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '--key-size'):
			keySize = int(value)
		elif (opt == '--ksk'):
			keyType = 'KSK'
		elif (opt == '--zsk'):
			keyType = 'ZSK'
		elif (opt == '--flags'):
			if (value not in ['256', '257']):
				raise CommandParserException("Key flags must be either 256 or 257")
			flags = int(value)
		elif (opt == '--status'):
			status = value.upper()
			if (status not in ['PUBLISH', 'NONE', 'SIGN']):
				raise CommandParserException("Key status must be either publish, sign or none")
	
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")
	
	newKeyRequest = NewKeyRequest()
	newKeyRequest.sessionId = sessionId
	newKeyRequest.zone = zonename
	newKeyRequest.keySize = keySize
	newKeyRequest.flags = flags
	newKeyRequest.keyStatus = DnskeyStatus(status)
	newKeyRequest.keyType = keyType
	xml = newKeyRequest.toXml()
	return xml

def parseImportKey(args, sessionId):
	opts, args = getopt.getopt(args, 'z:k:', ['ksk', 'zsk', 'flags=', 'status='])
	
	zonename = ''
	keyFile = ''
	keyType = 'ZSK'
	flags = DnskeyFlags.SEP_ON
	status = 'SIGN'
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '-k'):
			keyFile = value
		elif (opt == '--ksk'):
			keyType = 'KSK'
		elif (opt == '--zsk'):
			keyType = 'ZSK'
		elif (opt == '--flags'):
			if (value not in ['256', '257']):
				raise CommandParserException("Key flags must be either 256 or 257")
			flags = int(value)
		elif (opt == '--status'):
			status = value.upper()
			if (status not in ['PUBLISH', 'NONE', 'SIGN']):
				raise CommandParserException("Key status must be either publish, sign or none")
	
	if (zonename == '' or keyFile == ''):
		raise CommandParserException("Invalid syntax")
	
	keyData = readKeyFile(keyFile)
	importKeyRequest = ImportKeyRequest()
	importKeyRequest.sessionId = sessionId
	importKeyRequest.zone = zonename
	importKeyRequest.flags = flags
	importKeyRequest.keyType = keyType
	importKeyRequest.keyStatus = DnskeyStatus(status)
	importKeyRequest.algorithm = keyData["algorithm"]
	importKeyRequest.modulus = keyData["modulus"]
	importKeyRequest.publicExponent = keyData["publicExponent"]
	importKeyRequest.privateExponent = keyData["privateExponent"]
	importKeyRequest.prime1 = keyData["prime1"]
	importKeyRequest.prime2 = keyData["prime2"]
	importKeyRequest.exponent1 = keyData["exponent1"]
	importKeyRequest.exponent2 = keyData["exponent2"]
	importKeyRequest.coefficient = keyData["coefficient"]
	xml = importKeyRequest.toXml()
	return xml
	
def readKeyFile(filename):
	try:
		f = open(filename, 'r')
	except IOError, e:
		raise CommandParserException("Permission denied to read key file")
	
	lines = f.readlines()
	algorithm = ''
	modulus = ''
	publicExponent = ''
	privateExponent = ''
	prime1 = ''
	prime2 = ''
	exponent1 = ''
	exponent2 = ''
	coefficient = ''
	for l in lines:
		fields = l.split(' ')
		if (fields[0] == 'Algorithm:'):
			algorithm = fields[1].strip()
		elif (fields[0] == 'Modulus:'):
			modulus = fields[1].strip()
		elif (fields[0] == 'PublicExponent:'):
			publicExponent = fields[1].strip()
		elif (fields[0] == 'PrivateExponent:'):
			privateExponent = fields[1].strip()
		elif (fields[0] == 'Prime1:'):
			prime1 = fields[1].strip()
		elif (fields[0] == 'Prime2:'):
			prime2 = fields[1].strip()
		elif (fields[0] == 'Exponent1:'):
			exponent1 = fields[1].strip()
		elif (fields[0] == 'Exponent2:'):
			exponent2 = fields[1].strip()
		elif (fields[0] == 'Coefficient:'):
			coefficient = fields[1].strip()
			
	if (algorithm == '' or
			modulus == '' or
			publicExponent == '' or 
			privateExponent == '' or
			prime1 == '' or
			prime2 == '' or
			exponent1 == '' or
			exponent2 == '' or
			coefficient == ''):
		raise CommandParserException("Error: invalid file")
	
	key = {}
	key["algorithm"] = algorithm
	key["modulus"] = modulus
	key["publicExponent"] = publicExponent
	key["privateExponent"] = privateExponent
	key["prime1"] = prime1
	key["prime2"] = prime2
	key["exponent1"] = exponent1
	key["exponent2"] = exponent2
	key["coefficient"] = coefficient
	return key

def parseListKeys(args, sessionId):
	opts, args = getopt.getopt(args, 'z:')
	
	zonename = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
	
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")
	
	listKeys = ListKeysRequest()
	listKeys.sessionId = sessionId
	listKeys.zone = zonename
	xml = listKeys.toXml()
	return xml

def parseChangeKeyStatus(args, sessionId):
	opts, args = getopt.getopt(args, 'z:k:o:n:', ['old-status=', 'new-status='])
	
	zonename = ''
	keyName = ''
	oldStatus = ''
	newStatus = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '-k'):
			keyName = value
		elif (opt == '-o' or opt == '--old-status'):
			oldStatus = value.upper()
			if (oldStatus not in ['PUBLISH', 'NONE', 'SIGN']):
				raise CommandParserException("Key status must be either publish, sign or none")
		elif (opt == '-n' or opt == '--new-status'):
			newStatus = value.upper()
			if (newStatus not in ['PUBLISH', 'NONE', 'SIGN']):
				raise CommandParserException("Key status must be either publish, sign or none")
			
	if (zonename == '' or keyName == ''):
		raise CommandParserException("Invalid syntax")
	
	changeKeyRequest = ChangeKeyStatusRequest()
	changeKeyRequest.sessionId = sessionId
	changeKeyRequest.zone = zonename
	changeKeyRequest.key = keyName
	changeKeyRequest.oldStatus = DnskeyStatus(oldStatus)
	changeKeyRequest.newStatus = DnskeyStatus(newStatus)
	xml = changeKeyRequest.toXml()
	return xml

def parseRemoveKey(args, sessionId):
	opts, args = getopt.getopt(args, 'z:k:')
	
	zonename = ''
	keyName = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '-k'):
			keyName = value
			
	if (zonename == '' or keyName == ''):
		raise CommandParserException("Invalid syntax")
	
	removeKeyRequest = RemoveKeyRequest()
	removeKeyRequest.sessionId = sessionId
	removeKeyRequest.zone = zonename
	removeKeyRequest.key = keyName
	xml = removeKeyRequest.toXml()
	return xml

def parseSlaveGroupOperation(args, operation, sessionId):
	if (operation == SlaveOperation.ASSIGN or operation == SlaveOperation.UNASSIGN):
		options = 'z:g:'
	elif (operation == SlaveOperation.ADD or operation == SlaveOperation.REMOVE):
		options = 'g:'

	opts, args = getopt.getopt(args, options)
	zonename = ''
	slaveGroup = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
		elif (opt == '-g'):
			slaveGroup = value
	
	if (slaveGroup == ''):
		raise CommandParserException("Invalid syntax")
	
	if ((operation == SlaveOperation.ASSIGN or operation == SlaveOperation.UNASSIGN) and
			zonename == ''):
		raise CommandParserException("Invalid syntax")

	slaveGroupRequest = SlaveGroupRequest()
	slaveGroupRequest.sessionId = sessionId
	slaveGroupRequest.operation = operation
	slaveGroupRequest.slaveGroup = slaveGroup
	if (operation == SlaveOperation.ASSIGN or
			operation == SlaveOperation.UNASSIGN):
		slaveGroupRequest.zone = zonename

	xml = slaveGroupRequest.toXml()
	return xml

def parseListSlaveGroups(sessionId):
	listSlaveGroupRequest = ListSlaveGroupRequest()
	listSlaveGroupRequest.sessionId = sessionId
	xml = listSlaveGroupRequest.toXml()
	return xml

def parseListZonesBySlavegroup(args, sessionId):
	opts, args = getopt.getopt(args, 'g:')
	slaveGroup = ''
	for opt, value in opts:
		if (opt == '-g'):
			slaveGroup = value
	
	if (slaveGroup == ''):
		raise CommandParserException("Invalid syntax")
	
	listZonesRequest = ListZonesBySlaveGroupRequest()
	listZonesRequest.sessionId = sessionId
	listZonesRequest.slaveGroup = slaveGroup
	xml = listZonesRequest.toXml()
	return xml

def parsePrintSlaveGroup(args, sessionId):
	opts, args = getopt.getopt(args, 'g:')
	slaveGroup = ''
	for opt, value in opts:
		if (opt == '-g'):
			slaveGroup = value
	
	if (slaveGroup == ''):
		raise CommandParserException("Invalid syntax")
	
	printSlaveGroupRequest = PrintSlaveGroupRequest()
	printSlaveGroupRequest.sessionId = sessionId
	printSlaveGroupRequest.slaveGroup = slaveGroup
	xml = printSlaveGroupRequest.toXml()
	return xml

def parseSlaveOperation(args, operation, sessionId):
	opts, args = getopt.getopt(args, 'g:s:p:')
	slaveGroup = ''
	server = ''
	port = 53
	for opt, value in opts:
		if (opt == '-g'):
			slaveGroup = value
		elif (opt == '-s'):
			server = value
		elif (opt == '-p'):
			port = int(value)

	if (slaveGroup == '' or server == ''):
		raise CommandParserException("Invalid syntax")
	
	slaveRequest = SlaveRequest()
	slaveRequest.sessionId = sessionId
	slaveRequest.slaveGroup = slaveGroup
	slaveRequest.slave = server
	slaveRequest.port = port
	slaveRequest.operation = operation
	xml = slaveRequest.toXml()
	return xml

def parseListSlaves(args, sessionId):
	opts, args = getopt.getopt(args, 'z:')
	zonename = ''
	for opt, value in opts:
		if (opt == '-z'):
			zonename = value
	
	if (zonename == ''):
		raise CommandParserException("Invalid syntax")

	listSlavesRequest = ListSlavesRequest()
	listSlavesRequest.sessionId = sessionId
	listSlavesRequest.zone = zonename
	xml = listSlavesRequest.toXml()
	return xml

def parseNewTsigKey(args, sessionId):
	opts, args = getopt.getopt(args, 's:k:')
	server = ''
	keyName = ''
	for opt, value in opts:
		if (opt == '-s'):
			server = value
		elif (opt == '-k'):
			keyName = value

	if (server == '' or keyName == ''):
		raise CommandParserException("Invalid syntax")
	
	tsigKeyRequest = NewTsigKeyRequest()
	tsigKeyRequest.sessionId = sessionId
	tsigKeyRequest.host = server
	tsigKeyRequest.keyName = keyName
	xml = tsigKeyRequest.toXml()
	return xml

def parseRemoveTsigKey(args, sessionId):
	opts, args = getopt.getopt(args, 's:k:')
	server = ''
	keyName = ''
	for opt, value in opts:
		if (opt == '-s'):
			server = value
		elif (opt == '-k'):
			keyName = value

	if (server == '' or keyName == ''):
		raise CommandParserException("Invalid syntax")

	removeTsigKeyRequest = RemoveTsigKeyRequest()
	removeTsigKeyRequest.sessionId = sessionId
	removeTsigKeyRequest.host = server
	removeTsigKeyRequest.keyName = keyName
	xml = removeTsigKeyRequest.toXml()
	return xml

def parseListTsigKeys(args, sessionId):
	opts, args = getopt.getopt(args, 's:')
	server = ''
	for opt, value in opts:
		if (opt == '-s'):
			server = value

	if (server == ''):
		raise CommandParserException("Invalid syntax")

	listTsigKeysRequest = ListTsigKeysRequest()
	listTsigKeysRequest.sessionId = sessionId
	listTsigKeysRequest.host = server
	xml = listTsigKeysRequest.toXml()
	return xml

def parseAddZoneUser(args, sessionId):
	opts, args = getopt.getopt(args, 'z:u:')
	username = ''
	zone = ''
	
	for opt, value in opts:
		if (opt == '-u'):
			username = value
		elif (opt == '-z'):
			zone = value 
		
	if (username == '' or zone == ''):
		raise CommandParserException("Invalid syntax")
		
	addZoneUserRequest = AddZoneUserRequest()
	addZoneUserRequest.username = username
	addZoneUserRequest.zone = zone 
	addZoneUserRequest.sessionId = sessionId
	xml = addZoneUserRequest.toXml()
	return xml

def parseRemoveZoneUser(args, sessionId):
	opts, args = getopt.getopt(args, 'z:u:')
	username = ''
	zone = ''
	
	for opt, value in opts:
		if (opt == '-u'):
			username = value
		elif (opt == '-z'):
			zone = value 
		
	if (username == '' or zone == ''):
		raise CommandParserException("Invalid syntax")
		
	removeZoneUserRequest = RemoveZoneUserRequest()
	removeZoneUserRequest.username = username
	removeZoneUserRequest.zone = zone 
	removeZoneUserRequest.sessionId = sessionId
	xml = removeZoneUserRequest.toXml()
	return xml



	
