#  Copyright (C) 2009 Registro.br. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 1. Redistribution of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
 
from Cheetah.Template import Template
from DnskeyAlgorithm import DnskeyAlgorithm
from DnskeyFlags import DnskeyFlags
from DnskeyProtocol import DnskeyProtocol
from DnskeyStatus import DnskeyStatus
from DnskeyType import DnskeyType
from RestrictOperation import RestrictOperation

class NewKeyRequest(RestrictOperation):
	"""Request object for the newKey operation (Generate a new DNSKEY for a zone)."""
	TEMPLATE = """
<?xml version="1.0" encoding="UTF-8"?>
<dnsshim version="1.0">
	<request>
		<newKey>
			<sessionId>$request.sessionId</sessionId>
			<zone>$request.zone</zone>
			<size>$request.keySize</size>
			<type>$request.keyType</type>
			<flags>$request.flags</flags>
			<status>$request.keyStatus</status>
			<algorithm>$request.algorithm</algorithm>
			<protocol>$request.protocol</protocol>
		</newKey>
	</request>
</dnsshim>
	"""
	"""XML template for the request"""
	
	def __init__(self):
		"""Default constructor"""
		self.zone = ""
		"""Zonename"""
		self.keySize = 1024
		"""Size of the new key (default is 1024)"""
		self.algorithm = DnskeyAlgorithm.RSASHA1
		"""Algorithm of the new key (default is RSASHA1)"""
		self.flags = DnskeyFlags.SEP_ON
		"""Flags attribute of the new key (default is SEP_ON or 257)"""
		self.keyStatus = DnskeyStatus('SIGN')
		"""Key status (PUBLISH, SIGN or NONE) (default is SIGN)"""
		self.protocol = DnskeyProtocol.PROTOCOL
		"""Key protocol""" 
		self.keyType = DnskeyType.ZSK
		"""Keytype (ZSK or KSK) (default is ZSK)"""

	def toXml(self):
		"""
		Generate the request XML
		@return: Request XML document
		"""
		template = Template(self.TEMPLATE)
		template.request = self
		return str(template)