#  Copyright (C) 2009 Registro.br. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 1. Redistribution of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
 
from Response import Response
from ResponseStatus import ResponseStatus

from xml.dom.minidom import parseString
from StringIO import StringIO

class NewTsigKeyResponse(Response):
	"""Response object for the newTsigKey operation (generate a new TSIG key for a server)."""
	def __init__(self):
		"""Default constructor"""
		Response()
		self.host = ""
		"""IP address of the server"""
		self.keyName = ""
		"""Name of the new TSIG key"""
		self.secret = ""
		"""Secret of the new TSIG key"""
    
	def __str__(self):
		"""String representation of the object"""
		result = StringIO()
		print >> result, Response.__str__(self)
		if (self.status != ResponseStatus.OK):
			return result.getvalue()

		print >> result, "NewTsigKey:"
		print >> result, "\tHost: " + self.host
		print >> result, "\tKey Name: " + self.keyName
		print >> result, "\tsecret: " + self.secret
		return result.getvalue()
    
	def parseXml(self, xml):
		"""
		Parses a response XML document and fills the fields of the current object
		@param xml: Response XML document
		"""
		Response.parseXml(self, xml)
		if (self.status != ResponseStatus.OK):
			return
    
		dom = parseString(xml)

		keyNode = dom.getElementsByTagName("newTsigKey")[0]
		for childNode in keyNode.childNodes:
			nodeName = childNode.nodeName
			if (nodeName == "host"):
				self.host = childNode.firstChild.data
      
			elif (nodeName == "keyName"):
				self.keyName = childNode.firstChild.data
        
			elif (nodeName == "secret"):
				self.secret = childNode.firstChild.data